Script 'mail_helper' called by obssrc
Hello community,

here is the log from the commit of package python-invocations for 
openSUSE:Factory checked in at 2026-05-29 18:03:46
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/python-invocations (Old)
 and      /work/SRC/openSUSE:Factory/.python-invocations.new.1937 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "python-invocations"

Fri May 29 18:03:46 2026 rev:18 rq:1355731 version:4.0.2

Changes:
--------
--- /work/SRC/openSUSE:Factory/python-invocations/python-invocations.changes    
2026-04-13 23:18:27.255053794 +0200
+++ 
/work/SRC/openSUSE:Factory/.python-invocations.new.1937/python-invocations.changes
  2026-05-29 18:03:48.722180207 +0200
@@ -1,0 +2,7 @@
+Fri May 29 05:39:51 UTC 2026 - Steve Kowalik <[email protected]>
+
+- Add patch switch-to-blessed.patch:
+  * Use blessed, rather than blessings.
+- Add missing Requires on build and pip.
+
+-------------------------------------------------------------------

New:
----
  switch-to-blessed.patch

----------(New B)----------
  New:
- Add patch switch-to-blessed.patch:
  * Use blessed, rather than blessings.
----------(New E)----------

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ python-invocations.spec ++++++
--- /var/tmp/diff_new_pack.h3vx6p/_old  2026-05-29 18:03:50.198241257 +0200
+++ /var/tmp/diff_new_pack.h3vx6p/_new  2026-05-29 18:03:50.202241423 +0200
@@ -27,7 +27,9 @@
 Patch0:         invocations-no-bundled.patch
 # PATCH-FIX-OPENSUSE drop-icecream-dep.patch -- [email protected]
 Patch1:         drop-icecream-dep.patch
-BuildRequires:  %{python_module blessings >= 1.6}
+# PATCH-FIX-OPENSUSE switch to blessed
+Patch2:         switch-to-blessed.patch
+BuildRequires:  %{python_module blessed >= 1.6}
 BuildRequires:  %{python_module build >= 1.3}
 BuildRequires:  %{python_module invoke >= 1.7.2}
 BuildRequires:  %{python_module pip >= 25.2}
@@ -42,8 +44,10 @@
 BuildRequires:  %{python_module wheel >= 0.24.0}
 BuildRequires:  fdupes
 BuildRequires:  python-rpm-macros
-Requires:       python-blessings >= 1.6
+Requires:       python-blessed >= 1.6
+Requires:       python-build >= 1.3
 Requires:       python-invoke >= 1.7.2
+Requires:       python-pip >= 25.2
 Requires:       python-releases >= 1.6
 Requires:       python-semantic_version >= 2.4
 Requires:       python-tabulate >= 0.7.5

++++++ switch-to-blessed.patch ++++++
Index: invocations-4.0.2/pyproject.toml
===================================================================
--- invocations-4.0.2.orig/pyproject.toml
+++ invocations-4.0.2/pyproject.toml
@@ -16,7 +16,7 @@ dependencies = [
     # time if missing), but that got hairy fast, and these are all
     # pure-Python packages, so it shouldn't be a huge burden for users to
     # obtain them.
-    "blessings>=1.6",
+    "blessed>=1.6",
     "build>=1.3",
     # For envs that don't actually have pip - we use some of its tooling atm.
     "pip~=25.2",

Reply via email to
Index: invocations-4.0.2/invocations/packaging/release.py
===================================================================
--- invocations-4.0.2.orig/invocations/packaging/release.py
+++ invocations-4.0.2/invocations/packaging/release.py
@@ -24,7 +24,7 @@ try:
 except ImportError:
     from lexicon import Lexicon
 
-from blessings import Terminal
+from blessed import Terminal
 from docutils.utils import Reporter
 from enum import Enum
 from invoke import Collection, task, Exit
@@ -79,7 +79,7 @@ for key in ("halt_level", "report_level"
 # State junk
 #
 
 # Blessings Terminal object for ANSI colorization.
 # NOTE: mildly uncomfortable with the instance living at module level, but also
 # pretty sure it's unlikely to change meaningfully over time, between
 # threads/etc - and it'd be otherwise a PITA to cart around/re-instantiate.
@@ -79,7 +79,7 @@ for key in ("halt_level", "report_level"
 #
 
-# Blessings Terminal object for ANSI colorization.
+# Blessed Terminal object for ANSI colorization.
 # NOTE: mildly uncomfortable with the instance living at module level, but also
 # pretty sure it's unlikely to change meaningfully over time, between